/******************************************************************************
CLASSE READBIBLIA
CRIADO: 28-05-2008
ALTERADO: 19-01-2008
AUTOR: LUIS VASQUEZ - luis@comunidadeabiblia.net
WEB: www.comunidadeabiblia.net
--------------------------------aBblia Software-------------------------------
******************************************************************************/
#include "readbiblia.h"
#include "ferramentas.h"

ReadBiblia::ReadBiblia(const QString &strLivroCapitulo, short int idTestamento):ReadBiblico(){
	unsigned short int FONTE_GRANDE = resolucao.getFonteGrande();
	unsigned short int FONTE_MEDIA = resolucao.getFonteMedia();
	_strLivroCapitulo = strLivroCapitulo;
	_idTestamento = idTestamento;
	
	//Recupera config do comboLeitura
	comboLeitura = config.getCheckComboLeitura();

	// Tamanho e cone
	setMinimumSize( QSize( 600, 500 ) ); resize(600, 500);
	
	//Carrega as variveis strLivro e strCapitulo
	prepareLivroCapitulo(strLivroCapitulo);
	
	//Seta o ttulo da Janela
	setWindowTitle(strLivro + " " + strCapitulo);
	
	//Seta a fonte
	fonte = QFont("Bitstream", FONTE_MEDIA);
	
	//Abas Combo
	tabWidgetCombo = new QTabWidget( this );
	tabWidgetCombo->setFont(fonte);

	//Caixa de texto
	labelTexto->setText(config.getTextoPrincipal());
	caixaTexto->setText(carregarTexto(strLivroCapitulo, idTestamento, TEXTO_PRIMARIO));
	fonte = QFont("Bitstream", config.getPointSizeTexto("BIBLIA"));
	caixaTexto->setFont( fonte );
	fonte = QFont("Bitstream", FONTE_MEDIA);
	caixaTexto->setReadOnly(TRUE);

	//Caixa de texto Auxiliar
	fonte = QFont("Bitstream", FONTE_MEDIA);
	if (config.getCheckTextoSecundario()){
		labelTextoSecundario = new QLabel(this);
		labelTextoSecundario->setFont( fonte );
		labelTextoSecundario->setAlignment(Qt::AlignCenter);
		labelTextoSecundario->setText(config.getTextoSecundario());
		caixaTextoSecundario = new QTextBrowser(this);
		caixaTextoSecundario->setText(carregarTexto(strLivroCapitulo, idTestamento, TEXTO_SECUNDARIO));
		fonte = QFont("Bitstream", config.getPointSizeTexto("BIBLIA"));
		caixaTextoSecundario->setFont( fonte );
		fonte = QFont("Bitstream", FONTE_MEDIA);
		caixaTextoSecundario->setReadOnly(true);
	}

	//Caixa de texto Rodap
	caixaTextoRodape = new QTextEdit(this);
	caixaTextoRodape->setFont(fonte);
	if(!strLivro.isEmpty()){
		BancoUser bancoUser;
		caixaTextoRodape->setText( bancoUser.getAnotacao(strLivro, strCapitulo) );
		fonte = QFont("Bitstream", config.getPointSizeTexto("BIBLIA"));
		caixaTextoRodape->setFont( fonte );
		fonte = QFont("Bitstream", FONTE_MEDIA);
	}

	//Mostra Anotaes
	anotacoes = new QLabel(this);
	strAnotacoes = "Anotaes em " + strLivro + " " + strCapitulo;
	fonte = QFont("Bitstream", FONTE_GRANDE);
	fonteAnotacoes.setBold(TRUE);
	anotacoes->setText( strAnotacoes );
	anotacoes->setFont( fonte );
	
	//Combo Leitura
	btnComboLeitura = new QToolButton( this );
	btnComboLeitura->setAutoRaise(true);
	instanciarComboBiblia();
	setLivroCapituloInicialComboBiblia(idTestamento);
	setWindowState(Qt::WindowMaximized); //Forar primeira exeo maximizada

	//Menus
	salvarAnot = new QAction(tr("&Salvar anotaes"), this);
	salvarAnot->setShortcut(tr("Ctrl+S"));
	salvarAnot->setStatusTip(tr("Salvar as anotaes do rodap"));
	icon.load((const QString&)DIR_ICONS + "save.png");
	salvarAnot->setIcon(icon);
	QObject::connect(salvarAnot,SIGNAL(triggered() ),this,SLOT(slotSalvaCaixaRodape() ) );

	recarregarAnot = new QAction(tr("&Recarregar anotaes"), this);
	recarregarAnot->setShortcut(tr("Ctrl+R"));
	recarregarAnot->setStatusTip(tr("Recarregar as anotaes salvas do rodap"));
	icon.load((const QString&)DIR_ICONS + "reload.png");
	recarregarAnot->setIcon(icon);
	QObject::connect(recarregarAnot,SIGNAL(triggered() ),this,SLOT(slotRecarregaCaixaRodape() ) );

	limparAnot = new QAction(tr("&Limpar anotaes"), this);
	limparAnot->setShortcut(tr("Ctrl+L"));
	limparAnot->setStatusTip(tr("Limpar as anotaes do rodap"));
	icon.load((const QString&)DIR_ICONS + "generic.png");
	limparAnot->setIcon(icon);
	QObject::connect(limparAnot,SIGNAL(triggered() ),caixaTextoRodape,SLOT(clear() ) );

	arquivoMenu->addAction(salvarAnot);
	arquivoMenu->addAction(recarregarAnot);
	arquivoMenu->addAction(limparAnot);
	arquivoMenu->addSeparator();
	arquivoMenu->addAction(imprimir);
	arquivoMenu->addSeparator();
	arquivoMenu->addAction(sair);

	QObject::connect(caixaTextoRodape,SIGNAL(textChanged() ),this,SLOT(slotModificado() ) );
	//QObject::connect(caixaTextoRodape,SIGNAL(clicked() ),this,SLOT(slotVerificarConteudo() ) );
	QObject::connect(this,SIGNAL(salvarTexto() ),this,SLOT(slotSalvaCaixaRodape() ) );
	QObject::connect(btnComboLeitura,SIGNAL(clicked() ),this,SLOT(slotSetComboLeitura() ) );

	QObject::connect(aumentarFonte,SIGNAL(triggered() ),this, SLOT(slotZoomIn() ) );
	QObject::connect(diminuirFonte,SIGNAL(triggered() ),this, SLOT(slotZoomOut() ) );
	QObject::connect(actFontePadrao,SIGNAL(triggered() ),this, SLOT(slotZoomDefault() ) );
}

//Combo Ler Bblia
void ReadBiblia::instanciarComboBiblia(){
	unsigned short int FONTE_MEDIA = resolucao.getFonteMedia();
	unsigned short int FONTE_PEQUENA = resolucao.getFontePequena();
	
	//Padro
	boxComboPadrao = new QWidget(tabWidgetCombo);
	tabWidgetCombo->addTab( boxComboPadrao, "Padro");
	tabWidgetCombo->setTabToolTip(0, "Controle de leitura padro");

	fonte = QFont("Bitstream", FONTE_PEQUENA);
	lblAntTestamento = new QLabel(boxComboPadrao);
	lblAntTestamento->setText("Antigo Testamento");
	lblAntTestamento->setFont(fonte);
	lblAntTestamento->setAlignment( Qt::AlignHCenter );
	lblAntTestamento->setWordWrap(true);

	lblNovoTestamento = new QLabel(boxComboPadrao);
	lblNovoTestamento->setText("Novo Testamento");
	lblNovoTestamento->setFont(fonte);
	lblNovoTestamento->setAlignment( Qt::AlignHCenter );
	lblNovoTestamento->setWordWrap(true);

	fonte = QFont("Bitstream", FONTE_MEDIA);
	cbxLivroAntTestamento = new QComboBox( boxComboPadrao );
	cbxLivroAntTestamento->setFont(fonte);
	cbxLivroAntTestamento->setToolTip("Livros do Antigo Testamento");

	cbxCapituloAntTestamento = new QComboBox( boxComboPadrao );
	cbxCapituloAntTestamento->setFont(fonte);
	cbxCapituloAntTestamento->setToolTip("Captulos do livro selecionado");

	btnLerAntTestamento = new QPushButton("btnLerAntTestamento", boxComboPadrao );
	btnLerAntTestamento->setFont(fonte);
	btnLerAntTestamento->setText( tr( "Ler" ) );
	btnLerAntTestamento->setDefault(true);
	btnLerAntTestamento->setToolTip("Ler captulo selecionado");

	cbxLivroNovoTestamento = new QComboBox( boxComboPadrao );
	cbxLivroNovoTestamento->setFont(fonte);
	cbxLivroNovoTestamento->setToolTip("Livros do Novo Testamento");

	cbxCapituloNovoTestamento = new QComboBox( boxComboPadrao );
	cbxCapituloNovoTestamento->setFont(fonte);
	cbxCapituloNovoTestamento->setToolTip("Captulos do livro selecionado");

	btnLerNovoTestamento = new QPushButton("btnLerNovoTestamento", boxComboPadrao );
	btnLerNovoTestamento->setFont(fonte);
	btnLerNovoTestamento->setText( tr( "Ler" ) );
	btnLerNovoTestamento->setToolTip("Ler captulo selecionado");

	connect( cbxLivroAntTestamento, SIGNAL( activated (const QString&) ), this, SLOT(carregarLivroVelho() ) );
	connect( cbxCapituloAntTestamento, SIGNAL( activated (const QString&) ), this, SLOT(setVelhoDefault() ) );
	connect( btnLerAntTestamento, SIGNAL( clicked() ), this, SLOT( carregarCapituloVelho() ) );
	connect( cbxLivroNovoTestamento, SIGNAL( activated (const QString&) ), this, SLOT(carregarLivroNovo() ) );
	connect( cbxCapituloNovoTestamento, SIGNAL( activated (const QString&) ), this, SLOT(setNovoDefault() ) );
	connect( btnLerNovoTestamento, SIGNAL( clicked() ), this, SLOT( carregarCapituloNovo() ) );

	//Bsico
	boxComboBasico = new QWidget(tabWidgetCombo);
	tabWidgetCombo->addTab( boxComboBasico, "Bsico");
	tabWidgetCombo->setTabToolTip(1, "Controle de leitura bsico");
	
	boxLivro = new QGroupBox (boxComboBasico);
	boxLivro->setFont(fonte);
	boxLivro->setTitle("Livro");
	
	btnLivroProximo = new QPushButton("Prximo", boxLivro);
	btnLivroProximo->setToolTip("Prximo Livro");
	btnLivroProximo->setFont(fonte);
	
	btnLivroAnterior = new QPushButton("Anterior", boxLivro);
	btnLivroAnterior->setToolTip("Livro Anterior");
	btnLivroAnterior->setFont(fonte);
	
	boxCapitulo = new QGroupBox (boxComboBasico);
	boxCapitulo->setFont(fonte);
	boxCapitulo->setTitle("Captulo");
	
	btnCapituloProximo = new QPushButton("Prximo", boxCapitulo);
	btnCapituloProximo->setToolTip("Prximo Captulo");
	btnCapituloProximo->setFont(fonte);
	
	btnCapituloAnterior = new QPushButton("Anterior", boxCapitulo);
	btnCapituloAnterior->setToolTip("Captulo Anterior");
	btnCapituloAnterior->setFont(fonte);
	
	connect( btnLivroProximo, SIGNAL( clicked() ), this, SLOT( carregarLivroProximo() ) );
	connect( btnLivroAnterior, SIGNAL( clicked() ), this, SLOT( carregarLivroAnterior() ) );
	connect( btnCapituloProximo, SIGNAL( clicked() ), this, SLOT( carregarCapituloProximo() ) );
	connect( btnCapituloAnterior, SIGNAL( clicked() ), this, SLOT( carregarCapituloAnterior() ) );

	ordemBiblica();
	habilitarBotoesBasico();
	slotGetComboLeitura();
	
	if (config.getModoComboLeitura() == BASICO)
		tabWidgetCombo->setCurrentIndex(1);
}
//Padro
void ReadBiblia::carregarLivroVelho(){
	setVelhoDefault();
	carregarCapitulo(cbxLivroAntTestamento->currentText(), VELHO_TESTAMENTO);
}
void ReadBiblia::carregarCapituloVelho(){
	setTexto(cbxLivroAntTestamento->currentText(), cbxCapituloAntTestamento->currentText(), VELHO_TESTAMENTO);
}
void ReadBiblia::setVelhoDefault(){
	btnLerNovoTestamento->setDefault(false);
	btnLerAntTestamento->setDefault(true);
}
void ReadBiblia::carregarLivroNovo(){
	setNovoDefault();
	carregarCapitulo(cbxLivroNovoTestamento->currentText(), NOVO_TESTAMENTO);
}
void ReadBiblia::carregarCapituloNovo(){
	setTexto(cbxLivroNovoTestamento->currentText(), cbxCapituloNovoTestamento->currentText(), NOVO_TESTAMENTO);
}
void ReadBiblia::setNovoDefault(){
	btnLerNovoTestamento->setDefault(true);
	btnLerAntTestamento->setDefault(false);
}
void ReadBiblia::ordemBiblica(){
	BancoSystem bancoSystem;

	//Carregando os Livros do Velho testamento
	cbxLivroAntTestamento->clear();
	cbxLivroAntTestamento->addItems(bancoSystem.getLivros(VELHO_TESTAMENTO, PORTUGUES));

	//Carregando os Livros do Novo testamento
	cbxLivroNovoTestamento->clear();
	cbxLivroNovoTestamento->addItems(bancoSystem.getLivros(NOVO_TESTAMENTO, PORTUGUES));

	//Carregando os Capitulos do Velho e do Novo testamento
	carregarCapitulo(cbxLivroAntTestamento->currentText(), VELHO_TESTAMENTO);
	carregarCapitulo(cbxLivroNovoTestamento->currentText(), NOVO_TESTAMENTO);
}
//Bsico
void ReadBiblia::carregarLivroProximo(){
	carregarLivroProxAnt(PROXIMO, getIdTestamento());
}
void ReadBiblia::carregarLivroAnterior(){
	carregarLivroProxAnt(ANTERIOR, getIdTestamento());
}
void ReadBiblia::carregarCapituloProximo(){
	carregarCapituloProxAnt(PROXIMO, getIdTestamento());
}
void ReadBiblia::carregarCapituloAnterior(){
	carregarCapituloProxAnt(ANTERIOR, getIdTestamento());
}
void ReadBiblia::carregarLivroProxAnt(short int idOperacao, short int idTestamento){
	BancoSystem bancoSystem;
	
	QStringList strLivroTestamento = bancoSystem.getLivroProxAnt(strLivro, idTestamento, PORTUGUES, idOperacao);
	
	QVariant v;
	v.setValue(strLivroTestamento.at(1)); // idTestamento
	
	setTexto(strLivroTestamento.at(0), "01", v.toInt());
	
	//Atualizar Tab padro
	carregarCapitulo(strLivro, v.toInt());
	setLivroCapituloInicialComboBiblia(v.toInt());
}
void ReadBiblia::carregarCapituloProxAnt(short int idOperacao, short int idTestamento){
	BancoSystem bancoSystem;
	QVariant v;
	v.setValue(strCapitulo);
	int capitulo = v.toInt();
	
	if (idOperacao == PROXIMO){
		int qtdCap = bancoSystem.getQtdCapitulos(strLivro, idTestamento, PORTUGUES);
		if (v.toInt() < qtdCap)
			capitulo++; 
	}
	else
		if (capitulo > 1)
			capitulo--;
	
	v.setValue(capitulo);
	QString strCapituloLocal = v.toString();
	if (capitulo < 10)
		strCapituloLocal = "0" + strCapituloLocal;
	
	setTexto(strLivro, strCapituloLocal, idTestamento);
	
	//Atualizar Tab padro
	setLivroCapituloInicialComboBiblia(idTestamento);
}
void ReadBiblia::habilitarBotoesBasico(){
	BancoSystem bancoSystem;
	QVariant v;
	v.setValue(strCapitulo);
	int capitulo = v.toInt();
	
	int qtdCap = bancoSystem.getQtdCapitulos(strLivro, getIdTestamento(), PORTUGUES);
	
	if (capitulo == qtdCap)
		btnCapituloProximo->setEnabled(false);
	else
		btnCapituloProximo->setEnabled(true);
		
	if (capitulo == 1)
		btnCapituloAnterior->setEnabled(false);
	else
		btnCapituloAnterior->setEnabled(true);
		
	QStringList strLivroTestamento = bancoSystem.getLivroProxAnt(strLivro, getIdTestamento(), PORTUGUES, PROXIMO);
	
	if (strLivroTestamento.at(0).isEmpty())
		btnLivroProximo->setEnabled(false);
	else
		btnLivroProximo->setEnabled(true);
		
	strLivroTestamento = bancoSystem.getLivroProxAnt(strLivro, getIdTestamento(), PORTUGUES, ANTERIOR);

	if (strLivroTestamento.at(0).isEmpty())
		btnLivroAnterior->setEnabled(false);
	else
		btnLivroAnterior->setEnabled(true);
}
//Geral
void ReadBiblia::setTexto(const QString &strLivroLocal, const QString &strCapituloLocal, short int idTestamento){
	QString strLivroCapitulo = strLivroLocal + " " + strCapituloLocal;
	prepareLivroCapitulo(strLivroCapitulo);
	
	labelTexto->setText(config.getTextoPrincipal());
	caixaTexto->setText(carregarTexto(strLivroCapitulo, idTestamento, TEXTO_PRIMARIO));
	if (config.getCheckTextoSecundario()){
		labelTextoSecundario->setText(config.getTextoSecundario());
		caixaTextoSecundario->setText(carregarTexto(strLivroCapitulo, idTestamento, TEXTO_SECUNDARIO));
	}
	BancoUser bancoUser;
	strAnotacoes = "Anotaes em " + strLivro + " " + strCapitulo;
	caixaTextoRodape->setText( bancoUser.getAnotacao(strLivro, strCapitulo) );
	slotRecarregaCaixaRodape();
	
	_strLivroCapitulo = strLivro + " " + strCapitulo;
	_idTestamento = idTestamento;
	habilitarBotoesBasico();
	emit tituloAlterado(_strLivroCapitulo);
	
	//Armazenar estado das abas do combo de leitura
	setModoComboLeitura();
}

void ReadBiblia::slotGetComboLeitura(){
	if (comboLeitura){
		icon.load((const QString&)DIR_ICONS + "next.png");
		btnComboLeitura->setIcon(icon);
		btnComboLeitura->setToolTip("Esconder controle de leitura");
		lblAntTestamento->show();
		lblNovoTestamento->show();
		cbxLivroAntTestamento->show();
		cbxCapituloAntTestamento->show();
		btnLerAntTestamento->show();
		cbxLivroNovoTestamento->show();
		cbxCapituloNovoTestamento->show();
		btnLerNovoTestamento->show();
	}
	else {
		icon.load((const QString&)DIR_ICONS + "back.png");
		btnComboLeitura->setIcon(icon);
		btnComboLeitura->setToolTip("Exibir controle de leitura");
		lblAntTestamento->hide();
		lblNovoTestamento->hide();
		cbxLivroAntTestamento->hide();
		cbxCapituloAntTestamento->hide();
		btnLerAntTestamento->hide();
		cbxLivroNovoTestamento->hide();
		cbxCapituloNovoTestamento->hide();
		btnLerNovoTestamento->hide();
	}
	resizeRodape();
}
void ReadBiblia::slotSetComboLeitura(){
	if (comboLeitura){
		comboLeitura = false;
	}
	else {
		comboLeitura = true;
	}
	config.setCheckComboLeitura(comboLeitura);
	slotGetComboLeitura();
}

void ReadBiblia::setModoComboLeitura(){
	if (tabWidgetCombo->currentIndex() == 0)
		config.setModoComboLeitura(PADRAO);
	else
		config.setModoComboLeitura(BASICO);
}
void ReadBiblia::carregarCapitulo(const QString &livro, short int idTestamento){
	int cont, qtdVer = 0;
	QString cap;
	BancoSystem bancoSystem;

	if (idTestamento == VELHO_TESTAMENTO){
		//Antigo testamento
		cbxCapituloAntTestamento->clear();
		qtdVer = bancoSystem.getQtdCapitulos(livro, VELHO_TESTAMENTO, PORTUGUES);
	}
	else if (idTestamento == NOVO_TESTAMENTO){
		//Novo testamento
		cbxCapituloNovoTestamento->clear();
		qtdVer = bancoSystem.getQtdCapitulos(livro, NOVO_TESTAMENTO, PORTUGUES);
	}

	for (cont = 1; cont <= qtdVer; cont++){
		if (cont >= 1 && cont <= 9){
			cap.setNum(cont);
			cap.insert(0, "0");
		}
		else
			cap.setNum(cont);
		if (idTestamento == VELHO_TESTAMENTO)
			cbxCapituloAntTestamento->addItem(cap);
		else if (idTestamento == NOVO_TESTAMENTO)
			cbxCapituloNovoTestamento->addItem(cap);
	}
}
void ReadBiblia::setLivroCapituloInicialComboBiblia(short int idTestamento){
	BancoSystem bancoSystem;
	if (idTestamento == VELHO_TESTAMENTO){
		btnLerAntTestamento->setDefault(true);
		btnLerNovoTestamento->setDefault(false);
		cbxLivroAntTestamento->setCurrentIndex(bancoSystem.getIdLivro(strLivro, idTestamento, PORTUGUES));
		cbxCapituloAntTestamento->setCurrentIndex(strCapitulo.toInt() - 1);
	}
	else{
		btnLerAntTestamento->setDefault(false);
		btnLerNovoTestamento->setDefault(true);
		cbxLivroNovoTestamento->setCurrentIndex(bancoSystem.getIdLivro(strLivro, idTestamento, PORTUGUES));
		cbxCapituloNovoTestamento->setCurrentIndex(strCapitulo.toInt() - 1);
	}
}
//Fim - Combo Ler Bblia

void ReadBiblia::slotModificado(){
	anotacoes->setText(strAnotacoes + "*");
	setSalvo(false);
}

//Menus
void ReadBiblia::slotRecarregaCaixaRodape(){
	if(!strLivro.isEmpty()){
		BancoUser bancoUser;
		caixaTextoRodape->setText( bancoUser.getAnotacao(strLivro, strCapitulo) );
	}
	anotacoes->setText(strAnotacoes);
	setSalvo(true);
}

void ReadBiblia::slotSalvaCaixaRodape(){
	BancoUser bancoUser;
	if (!bancoUser.existAnotacao(strLivro, strCapitulo))
		bancoUser.setAnotacao(strLivro, strCapitulo, caixaTextoRodape->toPlainText());
	else
		bancoUser.editAnotacao(strLivro, strCapitulo, caixaTextoRodape->toPlainText());
	anotacoes->setText(strAnotacoes);
	setSalvo(true);
}

void ReadBiblia::slotZoomIn(){
	caixaTexto->zoomIn();
	if (config.getCheckTextoSecundario())
		caixaTextoSecundario->zoomIn();
	caixaTextoRodape->zoomIn();
	QFont fonteAtual = caixaTexto->currentFont();
	short int pointSize = fonteAtual.pointSize();
	config.setPointSizeTexto(pointSize, "BIBLIA");
}
void ReadBiblia::slotZoomOut(){
	caixaTexto->zoomOut();
	if (config.getCheckTextoSecundario())
		caixaTextoSecundario->zoomOut();
	caixaTextoRodape->zoomOut();
	QFont fonteAtual = caixaTexto->currentFont();
	short int pointSize = fonteAtual.pointSize();
	config.setPointSizeTexto(pointSize, "BIBLIA");
}
void ReadBiblia::slotZoomDefault(){
	config.setPointSizeTexto(resolucao.getFonteMedia(), "BIBLIA");
	QFont fonte = QFont("Bitstream", config.getPointSizeTexto("BIBLIA"));
	caixaTexto->setFont( fonte );
	if (config.getCheckTextoSecundario())
		caixaTextoSecundario->setFont( fonte );
	caixaTextoRodape->setFont( fonte );
}
QString ReadBiblia::getLivroCapitulo(){
	return _strLivroCapitulo;
}
int ReadBiblia::getIdTestamento(){
	return _idTestamento;
}
/*void ReadBiblia::slotVerificarConteudo(){
	AMessageBox aMsgBox;
	BancoUser bancoUser;
	
	if (bancoUser.existAnotacao(strLivro, strCapitulo))
		if (getSalvo())
			if(bancoUser.getAnotacao(strLivro, strCapitulo) != caixaTextoRodape->toPlainText())
				if (aMsgBox.yesNo("O contedo da anotaao foi modificado na base de dados.\n"
				"Deseja reverter o contedo atual pelo modificado?","Reverter contedo"))
					slotRecarregaCaixaRodape();
}*/
void ReadBiblia::resizeEvent(QResizeEvent * /*event*/){
	int extraWidth = width() - minimumWidth();
	int extraHeight = height() - minimumHeight();

	comunidade->setGeometry(10, 480 + extraHeight, 250, 25);
	
	resizeRodape();

	if (!config.getCheckTextoSecundario()){
		labelTexto->setGeometry(10, 33, 580 + extraWidth, 15);
		caixaTexto->setGeometry(10, 50, 580 + extraWidth, 300 + extraHeight);
		}
	else {
		labelTexto->setGeometry(10, 33, (580 + extraWidth)/2, 15);
		caixaTexto->setGeometry(10, 50, (580 + extraWidth)/2, 300 + extraHeight);
		labelTextoSecundario->setGeometry((580 + extraWidth)/2 + 10, 33, (580 + extraWidth)/2, 15);
		caixaTextoSecundario->setGeometry((580 + extraWidth)/2 + 10, 50, (580 + extraWidth)/2, 300 + extraHeight);
	}
}
void ReadBiblia::resizeRodape(){
	int extraWidth = width() - minimumWidth();
	int extraHeight = height() - minimumHeight();
	int larguraRodape = 580;
	
	if (comboLeitura){
		larguraRodape -= 320;
		tabWidgetCombo->show();

		#if defined(__linux__)
			tabWidgetCombo->setGeometry( QRect( larguraRodape + 20 + extraWidth, 356 + extraHeight, 310, 125 ) );
		#elif defined(_WIN32) || defined(__WIN32) || defined(WIN32) || defined(__WIN32__)
			tabWidgetCombo->setGeometry( QRect( larguraRodape + 20 + extraWidth, 358 + extraHeight, 310, 125 ) );
		#endif
		
		btnComboLeitura->setGeometry( QRect( larguraRodape + extraWidth - 15, 355 + extraHeight, 25, 25 ) );
		lblAntTestamento->setGeometry( QRect( 10, 3, 290, 20 ) );
		lblNovoTestamento->setGeometry( QRect( 10, 50, 290, 20 ) );
		cbxLivroAntTestamento->setGeometry( QRect( 10, 18, 150, 25 ) );
		cbxLivroNovoTestamento->setGeometry( QRect( 10, 65, 150, 25 ) );
		cbxCapituloAntTestamento->setGeometry( QRect( 170, 18, 50, 25 ) );
		cbxCapituloNovoTestamento->setGeometry( QRect( 170, 65, 50, 25 ) );
		btnLerAntTestamento->setGeometry( QRect( 230, 18, 65, 25 ) );
		btnLerNovoTestamento->setGeometry( QRect( 230, 65, 65, 25 ) );
		
		boxLivro->setGeometry( QRect( 10 , 25 , 135, 65 ) );
		btnLivroAnterior->setGeometry( QRect( 10, 30, 55, 25 ) );
		btnLivroProximo->setGeometry( QRect( 70, 30, 55, 25 ) );
		boxCapitulo->setGeometry( QRect( 160 , 25 , 135, 65 ) );
		btnCapituloAnterior->setGeometry( QRect( 10, 30, 55, 25 ) );
		btnCapituloProximo->setGeometry( QRect( 70, 30, 55, 25 ) );
	}
	else{
		tabWidgetCombo->hide();
		btnComboLeitura->setGeometry( QRect( width() - 35, 355 + extraHeight, 25, 25 ) );
	}
	caixaTextoRodape->setGeometry(10, 380 + extraHeight, larguraRodape + extraWidth, 101);
	anotacoes->setGeometry(20, 355 + extraHeight, larguraRodape, 26 );
	
}


//Operaes
QString ReadBiblia::carregarTexto(const QString &strLivroCapitulo, short int idTestamento, bool secundario){
	Ferramentas ferramentas;
	return ferramentas.separaCapitulos(strLivroCapitulo + ":", idTestamento, secundario);;
}

void ReadBiblia::liberarMemoria(){
	delete comunidade;
	delete labelTexto;
	delete caixaTexto;

	if (config.getCheckTextoSecundario()){
		delete labelTextoSecundario;
		delete caixaTextoSecundario;
	}
	//Rodape
	delete anotacoes;
	delete caixaTextoRodape;
	delete btnComboLeitura;
	delete lblAntTestamento;
	delete lblNovoTestamento;
	delete cbxCapituloNovoTestamento;
	delete cbxLivroNovoTestamento;
	delete btnLerNovoTestamento;
	delete btnLerAntTestamento;
	delete cbxCapituloAntTestamento;
	delete cbxLivroAntTestamento;
}

ReadBiblia::~ReadBiblia(){
	close();
}

